@@ -4,6 +4,7 @@ Node Item
 =========
 
 """
+import string
 
 from xml.sax.saxutils import escape
 
@@ -181,7 +182,6 @@ class NodeBodyItem(GraphicsPathObject):
             # Prevent the default bounding rect selection indicator.
             option.state = option.state ^ QStyle.State_Selected
         GraphicsPathObject.paint(self, painter, option, widget)
-
         if self.__progress >= 0:
             # Draw the progress meter over the shape.
             # Set the clip to shape so the meter does not overflow the shape.
@@ -191,7 +191,7 @@ class NodeBodyItem(GraphicsPathObject):
             painter.save()
             painter.setPen(pen)
             painter.setRenderHints(QPainter.Antialiasing)
-            span = int(self.__progress * 57.60)
+            span = max(1, int(self.__progress * 57.60))
             painter.drawArc(self.__shapeRect, 90 * 16, -span)
             painter.restore()
 
@@ -690,6 +690,74 @@ class GraphicsIconItem(QGraphicsItem):
             painter.drawPixmap(target, pixmap, QRectF(source))
 
 
+class NameTextItem(QGraphicsTextItem):
+    def __init__(self, *args, **kwargs):
+        super(NameTextItem, self).__init__(*args, **kwargs)
+        self.__selected = False
+        self.__palette = None
+
+    def paint(self, painter, option, widget=None):
+        if self.__selected:
+            painter.save()
+            painter.setPen(QPen(Qt.NoPen))
+            painter.setBrush(self.palette().color(QPalette.Highlight))
+            doc = self.document()
+            margin = doc.documentMargin()
+            painter.translate(margin, margin)
+            offset = min(margin, 2)
+            for line in self._lines(doc):
+                rect = line.naturalTextRect()
+                painter.drawRoundedRect(
+                    rect.adjusted(-offset, -offset, offset, offset),
+                    3, 3
+                )
+
+            painter.restore()
+
+        super(NameTextItem, self).paint(painter, option, widget)
+
+    def _blocks(self, doc):
+        block = doc.begin()
+        while block != doc.end():
+            yield block
+            block = block.next()
+
+    def _lines(self, doc):
+        for block in self._blocks(doc):
+            blocklayout = block.layout()
+            for i in range(blocklayout.lineCount()):
+                yield blocklayout.lineAt(i)
+
+    def setSelectionState(self, state):
+        if self.__selected != state:
+            self.__selected = state
+            self.__updateDefaultTextColor()
+            self.update()
+
+    def setPalatte(self, palette):
+        if self.__palette != palette:
+            self.__palette = palette
+            self.__updateDefaultTextColor()
+            self.update()
+
+    def palette(self):
+        if self.__palette is None:
+            scene = self.scene()
+            if scene is not None:
+                return scene.palette()
+            else:
+                return QPalette()
+        else:
+            return self.__palette
+
+    def __updateDefaultTextColor(self):
+        if self.__selected:
+            role = QPalette.HighlightedText
+        else:
+            role = QPalette.WindowText
+        self.setDefaultTextColor(self.palette().color(role))
+
+
 class NodeItem(QGraphicsObject):
     """
     An widget node item in the canvas.
@@ -740,6 +808,7 @@ class NodeItem(QGraphicsObject):
         self.__title = ""
         self.__processingState = 0
         self.__progress = -1
+        self.__statusMessage = ""
 
         self.__error = None
         self.__warning = None
@@ -804,7 +873,8 @@ class NodeItem(QGraphicsObject):
         self.outputAnchorItem.hide()
 
         # Title caption item
-        self.captionTextItem = QGraphicsTextItem(self)
+        self.captionTextItem = NameTextItem(self)
+
         self.captionTextItem.setPlainText("")
         self.captionTextItem.setPos(0, 33)
 
@@ -953,7 +1023,7 @@ class NodeItem(QGraphicsObject):
         """
         Set the node work progress state (number between 0 and 100).
         """
-        if progress is None or progress < 0:
+        if progress is None or progress < 0 or not self.__processingState:
             progress = -1
 
         progress = max(min(progress, 100), -1)
@@ -971,14 +1041,19 @@ class NodeItem(QGraphicsObject):
     progress_ = Property(float, fget=progress, fset=setProgress,
                          doc="Node progress state.")
 
-    def setProgressMessage(self, message):
+    def setStatusMessage(self, message):
         """
-        Set the node work progress message.
+        Set the node status message text.
 
-        .. note:: Not yet implemented
+        This text is displayed below the node's title.
 
         """
-        pass
+        if self.__statusMessage != message:
+            self.__statusMessage = unicode(message)
+            self.__updateTitleText()
+
+    def statusMessage(self):
+        return self.__statusMessage
 
     def setStateMessage(self, message):
         """
@@ -1108,13 +1183,34 @@ class NodeItem(QGraphicsObject):
         """
         Update the title text item.
         """
-        title_safe = escape(self.title())
-        if self.progress() > 0:
-            text = '<div align="center">%s<br/>%i%%</div>' % \
-                   (title_safe, int(self.progress()))
-        else:
-            text = '<div align="center">%s</div>' % \
-                   (title_safe)
+        text = ['<div align="center">%s' % escape(self.title())]
+
+        status_text = []
+
+        progress_included = False
+        if self.__statusMessage:
+            msg = escape(self.__statusMessage)
+            format_fields = dict(parse_format_fields(msg))
+            if "progress" in format_fields and len(format_fields) == 1:
+                # Insert progress into the status text format string.
+                spec, _ = format_fields["progress"]
+                if spec != None:
+                    progress_included = True
+                    progress_str = "{0:.0f}%".format(self.progress())
+                    status_text.append(msg.format(progress=progress_str))
+            else:
+                status_text.append(msg)
+
+        if self.progress() >= 0 and not progress_included:
+            status_text.append("%i%%" % int(self.progress()))
+
+        if status_text:
+            text += ["<br/>",
+                     '<span style="font-style: italic">',
+                     "<br/>".join(status_text),
+                     "</span>"]
+        text += ["</div>"]
+        text = "".join(text)
 
         # The NodeItems boundingRect could change.
         self.prepareGeometryChange()
@@ -1128,10 +1224,12 @@ class NodeItem(QGraphicsObject):
         Update message items (position, visibility and tool tips).
         """
         items = [self.errorItem, self.warningItem, self.infoItem]
+
         messages = [self.__error, self.__warning, self.__info]
         for message, item in zip(messages, items):
             item.setVisible(bool(message))
             item.setToolTip(message or "")
+
         shown = [item for item in items if item.isVisible()]
         count = len(shown)
         if count:
@@ -1176,6 +1274,7 @@ class NodeItem(QGraphicsObject):
     def itemChange(self, change, value):
         if change == QGraphicsItem.ItemSelectedChange:
             self.shapeItem.setSelected(value.toBool())
+            self.captionTextItem.setSelectionState(value.toBool())
         elif change == QGraphicsItem.ItemPositionHasChanged:
             self.positionChanged.emit()
 
@@ -1233,3 +1332,11 @@ def NodeItem_toolTipHelper(node, links_in=[], links_out=[]):
     tooltip = title + inputs + outputs
     style = "ul { margin-top: 1px; margin-bottom: 1px; }"
     return TOOLTIP_TEMPLATE.format(style=style, tooltip=tooltip)
+
+
+def parse_format_fields(format_str):
+    formatter = string.Formatter()
+    format_fields = [(field, (spec, conv))
+                     for _, field, spec, conv in formatter.parse(format_str)
+                     if field is not None]
+    return format_fields
