@@ -323,8 +323,13 @@ class CanvasScene(QGraphicsScene):
             item.setPos(pos)
 
         item.setTitle(node.title)
-        item.setProgress(node.progress)
         item.setProcessingState(node.processing_state)
+        item.setProgress(node.progress)
+
+        for message in node.state_messages():
+            item.setStateMessage(message)
+
+        item.setStatusMessage(node.status_message())
 
         self.__item_for_node[node] = item
 
@@ -333,6 +338,7 @@ class CanvasScene(QGraphicsScene):
         node.progress_changed.connect(item.setProgress)
         node.processing_state_changed.connect(item.setProcessingState)
         node.state_message_changed.connect(item.setStateMessage)
+        node.status_message_changed.connect(item.setStatusMessage)
 
         return self.add_node_item(item)
 
