@@ -92,6 +92,10 @@ class OWScatterPlot(OWWidget):
         self.outputs = [("Selected Data", ExampleTable), ("Other Data", ExampleTable)]
 
         self.graph = OWScatterPlotGraph(self, self.mainArea, "ScatterPlot")
+        self.graph.setSizePolicy(QSizePolicy.Preferred, QSizePolicy.Preferred)
+        self.graph.setMinimumSize(250, 200)
+        self.setSizePolicy(QSizePolicy.Preferred, QSizePolicy.Preferred)
+
         self.vizrank = OWVizRank(self, self.signalManager, self.graph, orngVizRank.SCATTERPLOT, "ScatterPlot")
         self.optimizationDlg = self.vizrank
 
@@ -255,6 +259,8 @@ class OWScatterPlot(OWWidget):
 
         self.closeContext()
         sameDomain = self.data and data and data.domain.checksum() == self.data.domain.checksum() # preserve attribute choice if the domain is the same
+        if data is not None and not hasattr(data, "name"):
+            data.name = "data"
         self.data = data
         self.vizrank.clearResults()
         if not sameDomain:
@@ -303,9 +309,17 @@ class OWScatterPlot(OWWidget):
 
     # send signals with selected and unselected examples as two datasets
     def sendSelections(self):
+        if not self.data:
+            return
         (selected, unselected) = self.graph.getSelectionsAsExampleTables([self.attrX, self.attrY])
-        self.send("Selected Data",selected)
-        self.send("Other Data",unselected)
+
+        if selected is not None and not hasattr(selected, "name"):
+            selected.name = self.data.name + " (selected)"
+        if unselected is not None and not hasattr(unselected, "name"):
+            selected.name = self.data.name + " (other)"
+
+        self.send("Selected Data", selected)
+        self.send("Other Data", unselected)
 
 
     # ##############################################################################################################################################################
@@ -376,6 +390,7 @@ class OWScatterPlot(OWWidget):
     def updateGraph(self, attrList = None, insideColors = None, **args):
         self.graph.zoomStack = []
         if not self.graph.haveData:
+            self.graph.replot()
             return
 
         if attrList and len(attrList) == 2:
@@ -396,6 +411,7 @@ class OWScatterPlot(OWWidget):
     # ##############################################################################################################################################################
     # SCATTERPLOT SETTINGS
     # ##############################################################################################################################################################
+
     def saveSettings(self):
         OWWidget.saveSettings(self)
         self.vizrank.saveSettings()
