@@ -14,10 +14,11 @@ RandomLearner = core.RandomLearner
 ClassifierFromVar = core.ClassifierFromVar
 ConstantClassifier = core.DefaultClassifier
 
+
 class PyLearner(object):
     def __new__(cls, data=None, **kwds):
         learner = object.__new__(cls)
-        if data:
+        if data is not None:
             learner.__init__(**kwds) # force init
             return learner(data)
         else:
@@ -29,9 +30,10 @@ class PyLearner(object):
     def __call__(self, data, weight=None):
         return None
 
+
 class PyClassifier:
     def __init__(self, **kwds):
         self.__dict__.update(kwds)
 
-    def __call__(self, example, resultType = Classifier.GetValue):
-        return self.classifier(example, resultType)
+    def __call__(self, example, result_type=Classifier.GetValue):
+        return self.classifier(example, result_type)
