@@ -1,11 +1,14 @@
 import math
 import random
 
-import Orange.core as orange
 import Orange
+import Orange.core
+import Orange.classification
 
 
-class BaggedLearner(orange.Learner):
+@Orange.utils.deprecated_members(
+    {"weightId": "weight_id", "examples": "instances"})
+class BaggedLearner(Orange.core.Learner):
     """
     BaggedLearner takes a learner and returns a bagged learner, which is
     essentially a wrapper around the learner passed as an argument. If
@@ -31,7 +34,7 @@ class BaggedLearner(orange.Learner):
             :class:`Orange.ensemble.bagging.BaggedLearner`
     """
     def __new__(cls, learner, instances=None, weight_id=None, **kwargs):
-        self = orange.Learner.__new__(cls, **kwargs)
+        self = Orange.core.Learner.__new__(cls, **kwargs)
         if instances is not None:
             self.__init__(self, learner, **kwargs)
             return self.__call__(instances, weight_id)
@@ -69,12 +72,15 @@ class BaggedLearner(orange.Learner):
         return BaggedClassifier(classifiers=classifiers, name=self.name, \
                     class_var=instances.domain.class_var)
 
-BaggedLearner = Orange.utils.deprecated_members(
-    {"weightId": "weight_id", "examples": "instances"}
-    )(BaggedLearner)
+    def __reduce__(self):
+        return type(self), (self.learner,), dict(self.__dict__)
 
 
-class BaggedClassifier(orange.Classifier):
+@Orange.utils.deprecated_members(
+    {"example": "instance",
+     "classVar": "class_var",
+     "resultType": "result_type"})
+class BaggedClassifier(Orange.core.Classifier):
     """
     A classifier that uses a bagging technique. Usually the learner
     (:class:`Orange.ensemble.bagging.BaggedLearner`) is used to construct the
@@ -100,7 +106,7 @@ class BaggedClassifier(orange.Classifier):
         self.class_var = class_var
         self.__dict__.update(kwds)
 
-    def __call__(self, instance, result_type=orange.GetValue):
+    def __call__(self, instance, result_type=Orange.classification.Classifier.GetValue):
         """
         :param instance: instance to be classified.
         :type instance: :class:`Orange.data.Instance`
@@ -118,28 +124,28 @@ class BaggedClassifier(orange.Classifier):
                 freq[int(c(instance))] += 1
             index = freq.index(max(freq))
             value = Orange.data.Value(self.class_var, index)
-            if result_type == orange.GetValue:
+            if result_type == Orange.classification.Classifier.GetValue:
                 return value
             for i in range(len(freq)):
                 freq[i] = freq[i] / len(self.classifiers)
             freq = Orange.statistics.distribution.Discrete(
                     freq, variable=self.class_var)
 
-            if result_type == orange.GetProbabilities:
+            if result_type == Orange.classification.Classifier.GetProbabilities:
                 return freq
-            elif result_type == orange.GetBoth:
+            elif result_type == Orange.classification.Classifier.GetBoth:
                 return (value, freq)
             else:
                 return value
 
         elif self.class_var.var_type == Orange.feature.Type.Continuous:
-            votes = [c(instance, orange.GetBoth \
-                       if result_type == orange.GetProbabilities \
+            votes = [c(instance, Orange.classification.Classifier.GetBoth \
+                       if result_type == Orange.classification.Classifier.GetProbabilities \
                        else result_type) \
                      for c in self.classifiers]
 
             wsum = float(len(self.classifiers))
-            if result_type in [orange.GetBoth, orange.GetProbabilities]:
+            if result_type in [Orange.classification.Classifier.GetBoth, Orange.classification.Classifier.GetProbabilities]:
                 pred = sum([float(c) for c, p in votes]) / wsum
 #               prob = sum([float(p.modus()) for c, p in votes]) / wsum
                 from collections import defaultdict
@@ -152,18 +158,13 @@ class BaggedClassifier(orange.Classifier):
                             prob, variable=self.class_var)
 
                 return (self.class_var(pred), prob) \
-                        if result_type == orange.GetBoth\
+                        if result_type == Orange.classification.Classifier.GetBoth\
                         else prob
 
-            elif result_type == orange.GetValue:
+            elif result_type == Orange.classification.Classifier.GetValue:
                 pred = sum([float(c) for c in votes]) / wsum
                 return self.class_var(pred)
 
     def __reduce__(self):
         return (type(self), (self.classifiers, self.name, self.class_var),
                 dict(self.__dict__))
-
-BaggedClassifier = Orange.utils.deprecated_members(
-    {"example": "instance", "classVar": "class_var",
-     "resultType": "result_type"}
-    )(BaggedClassifier)
