@@ -2,41 +2,58 @@ __docformat__ = 'restructuredtext'
 
 from operator import itemgetter
 
-import Orange.core as orange
+import Orange.data
 
 from Orange.feature.scoring import score_all
+import Orange
+
+
+def _select_features_subset(data, features):
+    """Select the `features` from the `data`.
+
+    .. note::
+        The `features` must be a subset of the `data.domain.features`.
+
+    """
+    def as_descriptor(arg):
+        """Ensure `arg` is an descriptor from `data.domain`"""
+        return data.domain[arg]
+
+    features = map(as_descriptor, features)
+    domain = Orange.data.Domain(features, data.domain.class_var,
+                                class_vars=data.domain.class_vars)
+    domain.add_metas(data.domain.get_metas())
+    return Orange.data.Table(domain, data)
+
 
 def top_rated(scores, n, highest_best=True):
     """Return n top-rated features from the list of scores.
 
-    :param scores: a list such as the one returned by
-      :obj:`~Orange.feature.scoring.score_all`
-    :type scores: list
-    :param n: number of features to select.
-    :type n: int
+    :param list scores:
+        A list such as the one returned by :func:`.score_all`
+    :param int n: Number of features to select.
+    :param bool highest_best:
+        If true, the features that are scored higher are preferred.
     :rtype: :obj:`list`
-    :param highest_best: if true, the features that are scored higher are preferred
-    :type highest_best: bool
+
     """
-    return [x[0] for x in \
-            sorted(scores, key=itemgetter(1), reverse=True)[:n]
-            ]
+    return [f for f, score in
+            sorted(scores, key=itemgetter(1), reverse=highest_best)[:n]]
 
 bestNAtts = top_rated
 
+
 def above_threshold(scores, threshold=0.0):
     """Return features (without scores) with scores above or
     equal to a specified threshold.
 
-    :param scores: a list such as one returned by
-      :obj:`~Orange.feature.scoring.score_all`
-    :type scores: list
-    :param threshold: threshold for selection
-    :type threshold: float
+    :param list scores:
+        A list such as one returned by :func:`.score_all`
+    :param float threshold: Threshold for selection.
     :rtype: :obj:`list`
 
     """
-    return [x[0] for x in scores if x[1] > threshold]
+    return [f for f, score in scores if score >= threshold]
 
 
 attsAboveThreshold = above_threshold
@@ -54,8 +71,10 @@ def select(data, scores, n):
     :param n: number of features to select
     :type n: int
     :rtype: :obj:`Orange.data.Table`
+
     """
-    return data.select(top_rated(scores, n) + [data.domain.classVar.name])
+    features = top_rated(scores, n)
+    return _select_features_subset(data, features)
 
 selectBestNAtts = select
 select_best_n = select
@@ -76,13 +95,13 @@ def select_above_threshold(data, scores, threshold=0.0):
     :type threshold: float
     :rtype: :obj:`Orange.data.Table`
     """
-    return data.select(above_threshold(scores, threshold) + \
-                       [data.domain.classVar.name])
+    features = above_threshold(scores, threshold)
+    return _select_features_subset(data, features)
 
 selectAttsAboveThresh = select_above_threshold
 
 
-def select_relief(data, measure=orange.MeasureAttribute_relief(k=20, m=50), margin=0):
+def select_relief(data, measure=Orange.feature.scoring.Relief(k=20, m=50), margin=0):
     """Iteratively remove the worst scored feature until no feature
     has a score below the margin. The filter procedure was originally
     designed for measures such as Relief, which are context dependent,
@@ -119,7 +138,7 @@ class FilterAboveThreshold(object):
     """
 
     def __new__(cls, data=None,
-                measure=orange.MeasureAttribute_relief(k=20, m=50),
+                measure=Orange.feature.scoring.Relief(k=20, m=50),
                 threshold=0.0):
         if data is None:
             self = object.__new__(cls)
@@ -128,7 +147,7 @@ class FilterAboveThreshold(object):
             self = cls(measure=measure, threshold=threshold)
             return self(data)
 
-    def __init__(self, measure=orange.MeasureAttribute_relief(k=20, m=50), \
+    def __init__(self, measure=Orange.feature.scoring.Relief(k=20, m=50), \
                  threshold=0.0):
         self.measure = measure
         self.threshold = threshold
@@ -160,7 +179,7 @@ class FilterBestN(object):
 
     """
     def __new__(cls, data=None,
-                measure=orange.MeasureAttribute_relief(k=20, m=50),
+                measure=Orange.feature.scoring.Relief(k=20, m=50),
                 n=5):
 
         if data is None:
@@ -170,7 +189,7 @@ class FilterBestN(object):
             self = cls(measure=measure, n=n)
             return self(data)
 
-    def __init__(self, measure=orange.MeasureAttribute_relief(k=20, m=50),
+    def __init__(self, measure=Orange.feature.scoring.Relief(k=20, m=50),
                  n=5):
         self.measure = measure
         self.n = n
@@ -196,7 +215,7 @@ class FilterRelief(object):
 
     """
     def __new__(cls, data=None,
-                measure=orange.MeasureAttribute_relief(k=20, m=50),
+                measure=Orange.feature.scoring.Relief(k=20, m=50),
                 margin=0):
 
         if data is None:
@@ -206,7 +225,7 @@ class FilterRelief(object):
             self = cls(measure=measure, margin=margin)
             return self(data)
 
-    def __init__(self, measure=orange.MeasureAttribute_relief(k=20, m=50),
+    def __init__(self, measure=Orange.feature.scoring.Relief(k=20, m=50),
                  margin=0):
         self.measure = measure
         self.margin = margin
@@ -264,7 +283,7 @@ class FilteredClassifier:
     def __init__(self, **kwds):
         self.__dict__.update(kwds)
 
-    def __call__(self, example, resultType=orange.GetValue):
+    def __call__(self, example, resultType=Orange.classification.Classifier.GetValue):
         return self.classifier(example, resultType)
 
     def atts(self):
