@@ -119,12 +119,20 @@ timeout = 120
 import urllib
 import urllib2
 import base64
+import functools
+
+from contextlib import contextmanager
 
 from Orange.utils import ConsoleProgressBar
+from . import environ
+
 import time, threading
 
 import os
 import shutil
+import tarfile
+import gzip
+import bz2
 import glob
 import datetime
 import tempfile
@@ -185,16 +193,12 @@ def _create_path(target):
 def localpath(domain=None, filename=None):
     """Return a path for the domain in the local repository. If 
     filename is given, return a path to corresponding file."""
-    import orngEnviron
     if not domain:
-        return os.path.join(orngEnviron.directoryNames["bufferDir"],
-            "bigfiles")
+        return os.path.join(environ.buffer_dir, "bigfiles")
     if filename:
-        return os.path.join(orngEnviron.directoryNames["bufferDir"],
-            "bigfiles", domain, filename)
+        return os.path.join(environ.buffer_dir, "bigfiles", domain, filename)
     else:
-        return os.path.join(orngEnviron.directoryNames["bufferDir"],
-            "bigfiles", domain)
+        return os.path.join(environ.buffer_dir, "bigfiles", domain)
 
 class ServerFiles(object):
     """
@@ -434,8 +438,88 @@ class ServerFiles(object):
             data["access_code"] = self.access_code
         return data
 
-def download(domain, filename, serverfiles=None, callback=None, 
-    extract=True, verbose=True):
+
+def _keyed_lock(lock_constructor=threading.Lock):
+    lock = threading.Lock()
+    locks = {}
+
+    def get_lock(key):
+        with lock:
+            if key not in locks:
+                locks[key] = lock_constructor()
+
+            return locks[key]
+    return get_lock
+
+
+class _Lock(object):
+    """
+    Like :class:`threading.Lock` but raises an error on reentrant acquire.
+    """
+    def __init__(self):
+        self.__lock = threading.RLock()
+        self.__locking_thread = None
+
+    def acquire(self, blocking=True):
+        if self.__lock.acquire(blocking):
+            if self.__locking_thread is None:
+                self.__locking_thread = threading.current_thread()
+            else:
+                assert self.__locking_thread == threading.current_thread()
+                self.__lock.release()
+                raise Exception("Recursive lock acquire!")
+
+            return True
+        else:
+            return False
+
+    def release(self):
+        assert self.__locking_thread is not None
+        self.__locking_thread = None
+        self.__lock.release()
+
+    def locked(self):
+        return self.__lock.locked()
+
+    def __enter__(self):
+        self.acquire()
+
+    def __exit__(self, *arg):
+        self.release()
+
+# _get_lock = _keyed_lock(threading.RLock)
+_get_lock = _keyed_lock(_Lock)
+
+
+@contextmanager
+def _lock_file(domain, filename, blocking=False):
+    path = localpath(domain, filename)
+    path = os.path.normpath(os.path.realpath(path))
+#     log.debug("locking: %s", path)
+    lock = _get_lock(path)
+    if lock.acquire(blocking):
+#         log.debug("got lock on: %s", path)
+        try:
+            yield
+        finally:
+            lock.release()
+#             log.debug("Released lock on: %s",  path)
+    else:
+        raise Exception("Could not acquire lock")
+
+
+def _locked(f):
+    @functools.wraps(f)
+    def func(domain, filename, *args, **kwargs):
+        with _lock_file(domain, filename, blocking=True):
+            return f(domain, filename, *args, **kwargs)
+    func.unwraped = f
+    return func
+
+
+@_locked
+def download(domain, filename, serverfiles=None, callback=None,
+             extract=True, verbose=True):
     """Downloads file from the repository to local orange installation.
     To download files as an authenticated user you should also pass an
     instance of ServerFiles class. Callback can be a function without
@@ -457,8 +541,8 @@ def download(domain, filename, serverfiles=None, callback=None,
     _save_file_info(target + '.info', info)
     
     if extract:
-        import tarfile, gzip, shutil
-        if specialtags.get("#compression") == "tar.gz" and specialtags.get("#files"):
+        if specialtags.get("#compression") in ["tar.gz", "tar.bz2"] and \
+                specialtags.get("#files"):
             f = tarfile.open(target + ".tmp")
             f.extractall(localpath(domain))
             shutil.copyfile(target + ".tmp", target)
@@ -472,12 +556,17 @@ def download(domain, filename, serverfiles=None, callback=None,
         elif specialtags.get("#compression") == "gz":
             f = gzip.open(target + ".tmp")
             shutil.copyfileobj(f, open(target, "wb"))
+        elif specialtags.get("#compression") == "bz2":
+            f = bz2.BZ2File(target + ".tmp", "r")
+            shutil.copyfileobj(f, open(target, "wb"))
         f.close()
         os.remove(target + ".tmp")
 
     if type(callback) == DownloadProgress:
         callback.finish()
 
+
+@_locked
 def localpath_download(domain, filename, **kwargs):
     """ 
     Return local path for the given domain and file. If file does not exist, 
@@ -485,7 +574,7 @@ def localpath_download(domain, filename, **kwargs):
     """
     pathname = localpath(domain, filename)
     if not os.path.exists(pathname):
-        download(domain, filename, **kwargs)
+        download.unwraped(domain, filename, **kwargs)
     return pathname
 
 def listfiles(domain):
@@ -509,6 +598,8 @@ def listfiles(domain):
 
     return okfiles
 
+
+@_locked
 def remove(domain, filename):
     """Remove a file from local repository."""
     filename = localpath(domain, filename)
