@@ -1,24 +1,3 @@
-/*
-    This file is part of Orange.
-    
-    Copyright 1996-2010 Faculty of Computer and Information Science, University of Ljubljana
-    Contact: janez.demsar@fri.uni-lj.si
-
-    Orange is free software: you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation, either version 3 of the License, or
-    (at your option) any later version.
-
-    Orange is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with Orange.  If not, see <http://www.gnu.org/licenses/>.
-*/
-
-
 #include <limits>
 #include <stdlib.h>
 
@@ -440,6 +419,10 @@ bool TPythonVariable::firstValue(TValue &val) const
     val = toValue(PyObject_CallMethod(MYSELF, "firstvalue", NULL));
     return true;
   }
+  if (isOverloaded("first_value")) {
+    val = toValue(PyObject_CallMethod(MYSELF, "first_value", NULL));
+    return true;
+  }
 
   else
     return TVariable::firstValue(val);
@@ -454,6 +437,12 @@ bool TPythonVariable::nextValue(TValue &val) const
     Py_DECREF(pyvalue);
     return true;
   }
+  if (isOverloaded("next_value")) {
+    PyObject *pyvalue = toPyObject(val);
+    toValue(PyObject_CallMethod(MYSELF, "next_value", "O", pyvalue), val);
+    Py_DECREF(pyvalue);
+    return true;
+  }
 
   else
     return TVariable::nextValue(val);
@@ -465,6 +454,9 @@ TValue TPythonVariable::randomValue(const int &rand)
   if (isOverloaded("randomvalue")) {
     return toValue(PyObject_CallMethod(MYSELF, "randomvalue", "i", rand));
   }
+  if (isOverloaded("random_value")) {
+    return toValue(PyObject_CallMethod(MYSELF, "random_value", "i", rand));
+  }
 
   else
     return TVariable::randomValue(rand);
